[![PyPI Package latest release](https://img.shields.io/pypi/v/limesqueezer.svg)][1]
[![PyPI Wheel](https://img.shields.io/pypi/wheel/limesqueezer.svg)][1]
[![Supported versions](https://img.shields.io/pypi/pyversions/limesqueezer.svg)][1]
[![Supported implementations](https://img.shields.io/pypi/implementation/limesqueezer.svg)][1]

# Limesqueezer <!-- omit in toc -->

Limesqueezer is a toolkit where NumPy array are lossily compressed using spline fitting.

## Table of Contents <!-- omit in toc -->

- [Quick start guide](#quick-start-guide)
    - [The first steps](#the-first-steps)
        - [Installing](#installing)
        - [Importing](#importing)

# Quick start guide

Here's how you can start

## The first steps

### Installing

Install Limesqueezer with pip

```
pip install limesqueezer
```

### Importing

Import name is the same as install name, `limesqueezer`.

```python
import limesqueezer
```

Since the package is accessed often,  abbreviation `ls` is used. The abbreviation is used throughout this document.

```python
import limesqueezer as ls
```

# Changelog <!-- omit in toc -->

## 1.0.13 2024-07-17 <!-- omit in toc -->

- Support for python 3.12

## 1.0.12 2022-07-16 <!-- omit in toc -->

- Changed README to Markdown-only
- Updated documentation
- Some refactoring
- Fixed type hints to pass MyPy type checking

## 1.0.11 2022-07-16 <!-- omit in toc -->

- Debug plotting improvements
- Added undocumented API for other fitting functions
- More tests
- Profiling and benchmarking from tests

## 1.0.10 2022-05-08 <!-- omit in toc -->

- Cleaned documentation

## 1.0.9 2022-04-03 <!-- omit in toc -->

- Block and stream compression are much more uniform
- Restructuring
- Tests
- Profiling

## 1.0.8 2022-03-20 <!-- omit in toc -->

- Step-by-step style ploting of the compression.

## 1.0.7 2021-12-07 <!-- omit in toc -->

## 1.0.6 2021-12-02 <!-- omit in toc -->

## 1.0.5 2021-12-02 <!-- omit in toc -->

## 1.0.4 2021-12-01 <!-- omit in toc -->

## 1.0.3 2021-11-30 <!-- omit in toc -->

- First release on PyPI.

[1]: <https://pypi.org/project/limesqueezer> "Project PyPI page"
